Crate int_traits

Provides a single trait IntTraits which provides extended traits for the integer type. These are typically special cases such as sqrt and are aimed primarily at reducing the incessant casting that is otherwise required for floored integer behaviour.

Traits

IntTraits
Provides functions which extended the class methods on integers.